authz

package module
v0.0.0-...-4596578 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 27, 2023 License: MIT Imports: 3 Imported by: 0

README

Authz

CodeQL Run Tests codecov Go Report Card GoDoc

Authz is an authorization middleware for Gin, it's based on https://github.com/casbin/casbin.

Installation

go get github.com/joncfa/authz

Simple Example

package main

import (
  "github.com/casbin/casbin/v2"
  "github.com/gin-contrib/authz"
  "github.com/gin-gonic/gin"
)

func main() {
  // load the casbin model and policy from files, database is also supported.
  e, _ := casbin.NewEnforcer("authz_model.conf", "authz_policy.csv")

  // define your router, and use the Casbin authz middleware.
  // the access that is denied by authz will return HTTP 403 error.
  router := gin.New()
  // Built in for BasicAuth but can pass in any func(r *http.Request) []string for custom subject processing i.e. jwt
  router.Use(authz.NewAuthorizer(e, GetSubjectBasicAuth))
}

Documentation

The authorization determines a request based on {subject, object, action}, which means what subject can perform what action on what object. In this plugin, the meanings are:

  1. subject: the logged-on username
  2. object: the URL path for the web resource like "dataset1/item1"
  3. action: HTTP method like GET, POST, PUT, DELETE, or the high-level actions you defined like "read-file", "write-blog"

For how to write authorization policy and other details, please refer to the Casbin's documentation.

Getting Help

License

This project is under MIT License. See the LICENSE file for the full license text.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetSubjectBasicAuth

func GetSubjectBasicAuth(r *http.Request) []string

GetUserName gets the user name from the request. Currently, only HTTP basic authentication is supported

func NewAuthorizer

func NewAuthorizer(e *casbin.Enforcer, getSubjects func(r *http.Request) []string) gin.HandlerFunc

NewAuthorizer returns the authorizer, uses a Casbin enforcer as input

Types

This section is empty.

Jump to